==> web-9.0.0.tgz: package/lib/button/GroupBtn.js <==
import * as React from "react";
import Button from "./MyButton";
import { SvgIcon } from "../my-icon/index";
class GroupBtn extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.clickFn = (e) => {
            const dom = e.currentTarget;
            const field = dom.dataset.field;
            const { clickFn } = this.props;
            clickFn(field);
        };
    }
    getBtns() {
        const { list } = this.props;
        return list.map(val => {
            const { text, id, icon } = val;
            const themeIcon = icon ? React.createElement(SvgIcon, { className: icon }) : undefined;
            return (React.createElement("li", { key: id, className: "drop-item", onClick: this.clickFn, "data-field": id },
                React.createElement("span", null,
                    themeIcon,
                    text)));
        });
    }
    render() {
        const { children, icon } = this.props;
        const themeIcon = icon ? React.createElement(SvgIcon, { className: icon }) : undefined;
        return (React.createElement("div", { className: "g-group-btns" },
            React.createElement("div", { className: "drop-theme" },
                React.createElement(Button, { noAnimate: true, className: icon ? "has-icon" : "" },
                    children,
                    themeIcon)),
            React.createElement("div", { className: "wrap-drop" },
                React.createElement("ul", { className: "drop-group" }, this.getBtns()))));
    }
}
export default GroupBtn;

==> web-11.0.2.tgz: package/lib/button/GroupBtn.js <==
import * as React from "react";
import Button from "./MyButton";
import { SvgIcon } from "../my-icon/index";
class GroupBtn extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.clickFn = (e) => {
            const dom = e.currentTarget;
            const field = dom.dataset.field;
            const { clickFn } = this.props;
            clickFn(field);
        };
    }
    getBtns() {
        const { list } = this.props;
        return list.map((val) => {
            const { text, id, icon } = val;
            const themeIcon = icon ? React.createElement(SvgIcon, { className: icon }) : undefined;
            return (React.createElement("li", { key: id, className: "drop-item", onClick: this.clickFn, "data-field": id },
                React.createElement("span", null,
                    themeIcon,
                    text)));
        });
    }
    render() {
        const { children, icon } = this.props;
        const themeIcon = icon ? React.createElement(SvgIcon, { className: icon }) : undefined;
        return (React.createElement("div", { className: "g-group-btns" },
            React.createElement("div", { className: "drop-theme" },
                React.createElement(Button, { noAnimate: true, className: icon ? "has-icon" : "" },
                    children,
                    themeIcon)),
            React.createElement("div", { className: "wrap-drop" },
                React.createElement("ul", { className: "drop-group" }, this.getBtns()))));
    }
}
export default GroupBtn;
